Crate starbase_shell

Crate starbase_shell 

Structs

Ash
Bash
Dash
Elvish
Fish
Ion
Murex
Nu
PowerShell
Pwsh
Quoter
A utility for quoting a string.
QuoterOptions
Options for Quoter.
Sh
Xonsh
Zsh

Enums

Hook
Quotable
A string of bytes that can be quoted/escaped.
ShellError
ShellType
Statement
Syntax
Types of syntax to check for to determine quoting.

Traits

Shell

Functions

apply_quote
default_escape_chars
join_exe_args
Join an executable and its arguments into a single string.

Type Aliases

BoxedShell